@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 
 #include "element.h"
 
-class PartitionKey: public Element {
+class __libcore PartitionKey: public Element {
 	private:
 		//! \brief Collation referenced by the element
 		Collation *collation;
@@ -41,7 +41,12 @@ class PartitionKey: public Element {
 		Collation *getCollation();
 
 		//! \brief Returns the SQL / XML code definition for the partition key
-		virtual QString getCodeDefinition(unsigned def_type) final;
+		virtual QString getSourceCode(SchemaParser::CodeType def_type) final;
 };
 
+/* Registering the PartitionKey class as a Qt MetaType in order to make
+ * it liable to be sent through signal parameters as well as to be
+ * to be used by QVariant */
+Q_DECLARE_METATYPE(PartitionKey)
+
 #endif
