@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,17 +27,26 @@
 
 #include "templatetype.h"
 
-class EncodingType: public TemplateType<EncodingType>{
+class __libcore EncodingType: public TemplateType<EncodingType>{
+	private:
+		static QStringList type_names;
+
 	public:
 		EncodingType();
 		EncodingType(const QString &type_name);
 		EncodingType(unsigned type_id);
 
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
+
 		bool operator == (const QString &type_name);
 		bool operator == (const char *type_name);
 		bool operator != (const QString &type_name);
 		bool operator != (EncodingType type);
-		bool operator != (unsigned tipo_id);
+		bool operator != (unsigned tipo_id) override;
 };
 
 #endif 
