@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 
 #include "templatetype.h"
 
-class EventTriggerType: public TemplateType<EventTriggerType>{
+class __libcore EventTriggerType: public TemplateType<EventTriggerType>{
+	private:
+		static QStringList type_names;
+
 	public:
 		static constexpr unsigned DdlCommandStart = 1,
 		DdlCommandEnd = 2,
@@ -37,6 +40,12 @@ class EventTriggerType: public TemplateType<EventTriggerType>{
 		EventTriggerType(const QString &type_name);
 		EventTriggerType(unsigned type_id);
 		EventTriggerType();
+
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
 };
 
 #endif 
