@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 
 #include "templatetype.h"
 
-class MatchType: public TemplateType<MatchType>{
+class __libcore MatchType: public TemplateType<MatchType>{
+	private:
+		static QStringList type_names;
+
 	public:
 		static constexpr unsigned Simple = 1,
 		Full = 2,
@@ -36,6 +39,12 @@ class MatchType: public TemplateType<MatchType>{
 		MatchType(unsigned type_id);
 		MatchType(const QString &type_name);
 		MatchType();
+
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
 };
 
 #endif 
