@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,15 +17,13 @@
 */
 
 #include "pgsqltype.h"
-#include "schemaparser.h"
 #include "attributes.h"
 
-vector<UserTypeConfig> PgSqlType::user_types;
+std::vector<UserTypeConfig> PgSqlType::user_types;
 
-template<>
-QStringList PgSqlType::TemplateType<PgSqlType>::type_names =
+QStringList PgSqlType::type_names =
 {
-	"", // Reserved for BaseType::null
+	"", // Reserved for Class::Null
 
 	//Types used by the class PgSQLType
 	//offsets 1 to 63
@@ -142,7 +140,7 @@ PgSqlType PgSqlType::parseString(const QString &str)
 		interv=intervals.back();
 		intervals.pop_back();
 
-		start=type_str.indexOf(QRegExp(QString("( )") + interv.toLower()));
+		start=type_str.indexOf(QRegularExpression(QString("( )") + interv.toLower()));
 		if(start>=0)
 		{
 			type_str.remove(start, interv.size()+1);
@@ -153,24 +151,24 @@ PgSqlType PgSqlType::parseString(const QString &str)
 	}
 
 	//Check if the type contains "with time zone" descriptor
-	with_tz=QRegExp(QString("(.)*(with time zone)(.)*")).exactMatch(type_str);
+	with_tz = QRegularExpression(QRegularExpression::anchoredPattern("(.)*(with time zone)(.)*")).match(type_str).hasMatch();
 
 	//Removes the timezone descriptor
-	type_str.remove(QRegExp(QString("(with)(out)*( time zone)")));
+	type_str.remove(QRegularExpression("(with)(out)*( time zone)"));
 
 	//Count the dimension of the type and removes the array descriptor
-	dim=type_str.count(QString("[]"));
-	type_str.remove(QString("[]"));
+	dim=type_str.count("[]");
+	type_str.remove("[]");
 
 	//Check if the type is a variable length type, e.g varchar(200)
-	if(QRegExp(QString("(.)+\\(( )*[0-9]+( )*\\)")).indexIn(type_str) >=0)
+	if(QRegularExpression("(.)+\\(( )*[0-9]+( )*\\)").match(type_str).hasMatch())
 	{
 		start=type_str.indexOf('(');
 		end=type_str.indexOf(')', start);
 		len=type_str.mid(start+1, end-start-1).toInt();
 	}
 	//Check if the type is a numeric type, e.g, numeric(10,2)
-	else if(QRegExp(QString("(.)+\\(( )*[0-9]+( )*(,)( )*[0-9]+( )*\\)")).indexIn(type_str) >=0)
+	else if(QRegularExpression("(.)+\\(( )*[0-9]+( )*(,)( )*[0-9]+( )*\\)").match(type_str).hasMatch())
 	{
 		start=type_str.indexOf('(');
 		end=type_str.indexOf(')', start);
@@ -179,7 +177,8 @@ PgSqlType PgSqlType::parseString(const QString &str)
 		prec=value[1].toUInt();
 	}
 	//Check if the type is a spatial type (PostGiS), e.g, geography(POINTZ, 4296)
-	else if(QRegExp(QString("(.)+\\(( )*[a-z]+(( )*(,)( )*[0-9]+( )*)?\\)"), Qt::CaseInsensitive).indexIn(type_str) >=0)
+	else if(QRegularExpression("(.)+\\(( )*[a-z]+(( )*(,)( )*[0-9]+( )*)?\\)",
+														 QRegularExpression::CaseInsensitiveOption).match(type_str).hasMatch())
 	{
 		start=type_str.indexOf('(');
 		end=type_str.indexOf(')', start);
@@ -218,7 +217,7 @@ PgSqlType PgSqlType::parseString(const QString &str)
 			{
 				/* One last try it to check if the type has an entry on user defined types
 			 as pg_catalog.[type name] */
-				type=PgSqlType(QString("pg_catalog.") + type_str);
+				type=PgSqlType("pg_catalog." + type_str);
 			}
 		}
 
@@ -272,7 +271,7 @@ unsigned PgSqlType::setType(unsigned type_id)
 	if(type_id >= static_cast<unsigned>(type_names.size()))
 		return setUserType(type_id);
 
-	unsigned tp_idx = TemplateType<PgSqlType>::setType(type_id);
+	unsigned tp_idx = TemplateType<PgSqlType>::setType(type_id, type_names);
 
 	return tp_idx;
 }
@@ -288,7 +287,7 @@ unsigned PgSqlType::setType(const QString &type_name)
 		throw Exception(ErrorCode::AsgInvalidTypeObject,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
 	if(type_id != Null)
-		return setType(type_id);
+		return TemplateType<PgSqlType>::setType(type_id, type_names);
 
 	return setUserType(usr_type_id);
 }
@@ -381,7 +380,7 @@ QString PgSqlType::getSQLTypeName()
 		{
 			aux = type_names[type_idx];
 
-			if(interval_type!=BaseType::Null)
+			if(interval_type!=IntervalType::Null)
 				aux+=QString(" %1 ").arg(~interval_type);
 
 			if(precision >= 0)
@@ -401,12 +400,17 @@ QString PgSqlType::getSQLTypeName()
 	return fmt_type;
 }
 
+QStringList PgSqlType::getTypes()
+{
+	return TemplateType<PgSqlType>::getTypes(type_names);
+}
+
 bool PgSqlType::isRegistered(const QString &type, void *pmodel)
 {
-	if(getBaseTypeIndex(type)!=BaseType::Null)
+	if(getBaseTypeIndex(type)!=PgSqlType::Null)
 		return true;
 	else
-		return (getUserTypeIndex(type, nullptr, pmodel)!=BaseType::Null);
+		return (getUserTypeIndex(type, nullptr, pmodel)!=PgSqlType::Null);
 }
 
 bool PgSqlType::operator == (unsigned type_id)
@@ -516,16 +520,17 @@ unsigned PgSqlType::setUserType(void *ptype)
 	return type_idx;
 }
 
-void PgSqlType::addUserType(const QString &type_name, void *ptype, void *pmodel, unsigned type_conf)
+void PgSqlType::addUserType(const QString &type_name, void *ptype, void *pmodel, UserTypeConfig::TypeConf type_conf)
 {
 	if(!type_name.isEmpty() && ptype && pmodel &&
-			(type_conf==UserTypeConfig::DomainType ||
+			/*(type_conf==UserTypeConfig::DomainType ||
 			 type_conf==UserTypeConfig::SequenceType ||
 			 type_conf==UserTypeConfig::TableType ||
 			 type_conf==UserTypeConfig::ViewType ||
 			 type_conf==UserTypeConfig::ExtensionType ||
 			 type_conf==UserTypeConfig::ForeignTableType ||
-			 type_conf==UserTypeConfig::BaseType) &&
+			 type_conf==UserTypeConfig::BaseType)*/
+			type_conf != UserTypeConfig::AllUserTypes &&
 			getUserTypeIndex(type_name,ptype,pmodel)==0)
 	{
 		UserTypeConfig cfg;
@@ -543,7 +548,7 @@ void PgSqlType::removeUserType(const QString &type_name, void *ptype)
 	if(PgSqlType::user_types.size() > 0 &&
 			!type_name.isEmpty() && ptype)
 	{
-		vector<UserTypeConfig>::iterator itr, itr_end;
+		std::vector<UserTypeConfig>::iterator itr, itr_end;
 
 		itr=PgSqlType::user_types.begin();
 		itr_end=PgSqlType::user_types.end();
@@ -568,7 +573,7 @@ void PgSqlType::renameUserType(const QString &type_name, void *ptype,const QStri
 	if(PgSqlType::user_types.size() > 0 &&
 			!type_name.isEmpty() && ptype && type_name!=new_name)
 	{
-		vector<UserTypeConfig>::iterator itr, itr_end;
+		std::vector<UserTypeConfig>::iterator itr, itr_end;
 
 		itr=PgSqlType::user_types.begin();
 		itr_end=PgSqlType::user_types.end();
@@ -589,7 +594,7 @@ void PgSqlType::removeUserTypes(void *pmodel)
 {
 	if(pmodel)
 	{
-		vector<UserTypeConfig>::iterator itr;
+		std::vector<UserTypeConfig>::iterator itr;
 		unsigned idx=0;
 
 		itr=user_types.begin();
@@ -614,7 +619,7 @@ unsigned PgSqlType::getBaseTypeIndex(const QString &type_name)
 	QString aux_name=type_name;
 
 	aux_name.remove(QString("[]"));
-	aux_name.remove(QRegExp(QString("( )(with)(out)?(.)*")));
+	aux_name.remove(QRegularExpression(QString("( )(with)(out)?(.)*")));
 	aux_name=aux_name.trimmed();
 	return getType(aux_name, type_names);
 }
@@ -623,7 +628,7 @@ unsigned PgSqlType::getUserTypeIndex(const QString &type_name, void *ptype, void
 {
 	if(user_types.size() > 0 && (!type_name.isEmpty() || ptype))
 	{
-		vector<UserTypeConfig>::iterator itr, itr_end;
+		std::vector<UserTypeConfig>::iterator itr, itr_end;
 		int idx=0;
 
 		itr=user_types.begin();
@@ -643,9 +648,9 @@ unsigned PgSqlType::getUserTypeIndex(const QString &type_name, void *ptype, void
 		if(itr!=itr_end)
 			return (PseudoEnd + 1 + idx);
 		else
-			return BaseType::Null;
+			return PgSqlType::Null;
 	}
-	else return BaseType::Null;
+	else return PgSqlType::Null;
 }
 
 QString PgSqlType::getUserTypeName(unsigned type_id)
@@ -679,7 +684,7 @@ void PgSqlType::getUserTypes(QStringList &type_list, void *pmodel, unsigned inc_
 	}
 }
 
-void PgSqlType::getUserTypes(vector<void *> &ptypes, void *pmodel, unsigned inc_usr_types)
+void PgSqlType::getUserTypes(std::vector<void *> &ptypes, void *pmodel, unsigned inc_usr_types)
 {
 	unsigned idx, total;
 
@@ -855,7 +860,7 @@ bool PgSqlType::acceptsPrecision()
 
 void PgSqlType::reset(bool all_attrs)
 {
-	setIntervalType(BaseType::Null);
+	setIntervalType(IntervalType::Null);
 	setSpatialType(SpatialType());
 	setPrecision(-1);
 	setLength(0);
@@ -900,7 +905,7 @@ bool PgSqlType::canCastTo(PgSqlType type)
 bool PgSqlType::isEquivalentTo(PgSqlType type)
 {
 	unsigned this_idx=0, type_idx=0;
-	static vector<QStringList> types={{QString("int2"),QString("smallint")},
+	static std::vector<QStringList> types={{QString("int2"),QString("smallint")},
 																		{QString("int4"),QString("integer")},
 																		{QString("int8"),QString("bigint")},
 																		{QString("decimal"),QString("numeric")},
@@ -952,14 +957,14 @@ PgSqlType PgSqlType::getAliasType()
 {
 	if(!isUserType())
 	{
-		if(type_names[this->type_idx]==QString("serial"))
-			return (PgSqlType(QString("integer")));
+		if(type_names[this->type_idx]=="serial")
+			return (PgSqlType("integer"));
 
-		if(type_names[this->type_idx]==QString("smallserial"))
-			return (PgSqlType(QString("smallint")));
+		if(type_names[this->type_idx]=="smallserial")
+			return (PgSqlType("smallint"));
 
-		if(type_names[this->type_idx]==QString("bigserial"))
-			return (PgSqlType(QString("bigint")));
+		if(type_names[this->type_idx]=="bigserial")
+			return (PgSqlType("bigint"));
 
 		return (PgSqlType(type_names[this->type_idx]));
 	}
@@ -1019,9 +1024,9 @@ int PgSqlType::getPrecision()
 	return precision;
 }
 
-QString PgSqlType::getCodeDefinition(unsigned def_type,QString ref_type)
+QString PgSqlType::getSourceCode(SchemaParser::CodeType def_type, QString ref_type)
 {
-	if(def_type==SchemaParser::SqlDefinition)
+	if(def_type==SchemaParser::SqlCode)
 		return getSQLTypeName();
 
 	attribs_map attribs;
@@ -1046,7 +1051,7 @@ QString PgSqlType::getCodeDefinition(unsigned def_type,QString ref_type)
 	if(precision >= 0)
 		attribs[Attributes::Precision]=QString("%1").arg(this->precision);
 
-	if(interval_type != BaseType::Null)
+	if(interval_type != IntervalType::Null)
 		attribs[Attributes::IntervalType]=(~interval_type);
 
 	if(isGeoType())
@@ -1059,7 +1064,7 @@ QString PgSqlType::getCodeDefinition(unsigned def_type,QString ref_type)
 	if(with_timezone)
 		attribs[Attributes::WithTimezone]=Attributes::True;
 
-	return schparser.getCodeDefinition(Attributes::PgSqlBaseType, attribs, def_type);
+	return schparser.getSourceCode(Attributes::PgSqlBaseType, attribs, def_type);
 }
 
 QString PgSqlType::operator * ()
