@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,14 +26,14 @@
 
 #include "basefunction.h"
 
-class Procedure: public BaseFunction {
+class __libcore Procedure: public BaseFunction {
 	public:
 		Procedure();
 
 		virtual void addParameter(Parameter param);
-		virtual QString getCodeDefinition(unsigned def_type, bool) final;
-		virtual QString getCodeDefinition(unsigned def_type) final;
-		virtual QString getAlterDefinition(BaseObject *object) final;
+		virtual QString getSourceCode(SchemaParser::CodeType def_type, bool) final;
+		virtual QString getSourceCode(SchemaParser::CodeType def_type) final;
+		virtual QString getAlterCode(BaseObject *object) final;
 };
 
 #endif
