@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -116,7 +116,19 @@ Must be manually simulated using the available binary relationships.
 			weak entity tuples must be destroyed also because this latter exists only because
 			the first. */
 
-class Relationship: public BaseRelationship {
+class __libcore Relationship: public BaseRelationship {
+	public:
+		//! \brief Patterns ids
+		enum PatternId: unsigned {
+			SrcColPattern,
+			DstColPattern,
+			SrcFkPattern,
+			DstFkPattern,
+			PkPattern,
+			UqPattern,
+			PkColPattern
+		};
+
 	private:
 		/*! \brief Indicates that the relationship invalid because one or more critical attributes
 		 where modified needing to be revalidated */
@@ -135,7 +147,7 @@ class Relationship: public BaseRelationship {
 
 		/*! \brief Stores the columns which are created to be referenced by foreign keys
 			in order to represent the relationship */
-		vector<Column *> gen_columns,
+		std::vector<Column *> gen_columns,
 
 		/*! \brief Stores the primary key columns which from the referenced table
 				This vector is used by the relationship validation method. */
@@ -150,16 +162,16 @@ class Relationship: public BaseRelationship {
 			of connection the old names stored on this map are assigned to columns
 			related to each primary key column that generates the referenced columns
 			and finally this map is cleared */
-		map<unsigned, QString> prev_ref_col_names;
+		std::map<unsigned, QString> prev_ref_col_names;
 
 		//! \brief This map stores the name patterns for objects generated by relationship
-		map<unsigned, QString> name_patterns;
+		std::map<unsigned, QString> name_patterns;
 
 		//! \brief Relationship attributes (used as columns on the receiver table)
-		vector<TableObject *> rel_attributes;
+		std::vector<TableObject *> rel_attributes;
 
 		//! \brief Relationship constraint (used as constraints on the receiver table)
-		vector<TableObject *> rel_constraints;
+		std::vector<TableObject *> rel_constraints;
 
 		//! \brief Foreign key that represents the 1-n relationship
 		Constraint *fk_rel1n,
@@ -179,7 +191,7 @@ class Relationship: public BaseRelationship {
 		*uq_rel11;
 
 		//! \brief Stores the CHECK constraints copied from the parent table to its child
-		vector<Constraint *> ck_constraints;
+		std::vector<Constraint *> ck_constraints;
 
 		//! \brief Table created by the relationship n-n
 		Table *table_relnn;
@@ -202,7 +214,7 @@ class Relationship: public BaseRelationship {
 
 		/*! \brief This vector allows the user to define which columns inherited / copied (via its indexes)
 		 will be used on the special primary key in the receiver table */
-		vector<unsigned> column_ids_pk_rel;
+		std::vector<unsigned> column_ids_pk_rel;
 
 		//! \brief Name assigned to the generated table on n-n relationships
 		QString tab_name_relnn,
@@ -225,13 +237,16 @@ class Relationship: public BaseRelationship {
 		void addColumnsRelNn();
 
 		/*! \brief Copy columns from one table to another. This operation is done in
-		 relationships of type copy / generalization. It is necessary
-		 to check duplicate names and incompatible types of columns */
-		void addColumnsRelGenPart();
+		 *  relationships of type copy / generalization. It is necessary
+		 *  to check duplicate names and incompatible types of columns. */
+		void addColumnsRelGenPart(bool missing_only = false);
 
 		/*! \brief Copy constraints from the parent table to the child. Currently, only
 		check constraints are copied only if the NO INHERIT attribute is not set and
 		there are no conflicting constraints (name or expression) on the child table */
+		void addCheckConstrsRelGenPart();
+
+		//! \brief Creates the special primary key (if in use) and other relationship constraints in the receiver table.
 		void addConstraintsRelGenPart();
 
 		/*! \brief Creates the foreign key that represents the relationship and adds it
@@ -257,7 +272,7 @@ class Relationship: public BaseRelationship {
 		/*! \brief Copy the columns from the reference table to the receiver table. The parameter not_null indicates
 		 that the columns must not accept null values. The parameter is_dst_table is used to force the usage of destination table
 		and destination name pattern when creating a self many-to-many relationship */
-		void copyColumns(PhysicalTable *ref_tab, PhysicalTable *recv_tab, bool not_null, bool is_dst_table = false);
+		void copyColumns(PhysicalTable *ref_tab, PhysicalTable *recv_tab, bool not_null, bool is_dst_table = false, bool missing_only = false);
 
 		/*! \brief This method is always executed before disconnection of the relationship.
 		 Its function is to remove from the specified table all the attributes which
@@ -274,16 +289,19 @@ class Relationship: public BaseRelationship {
 		void removeColumnFromTablePK(PhysicalTable *table, Column *column);
 
 		//! \brief Generates the object name according to the specified name pattern
-		QString generateObjectName(unsigned pat_id, Column *id_col=nullptr, bool use_alias=false);
+		QString generateObjectName(PatternId pat_id, Column *id_col=nullptr, bool use_alias=false);
 
 		void setOriginalPrimaryKey(Constraint *pk);
 
+		//! \brief Adds the generated columns and relationshp attributes to the special primary key (if in use)
+		void addGeneratedColsToSpecialPk();
+
 	protected:
 		//! \brief Destroy all the relationship attributes and constraints
 		void destroyObjects();
 
 		//! \brief Returns all the refenced columns of the relationship
-		vector<Column *> getGeneratedColumns();
+		std::vector<Column *> getGeneratedColumns();
 
 		//! \brief Returns the table generated by the n-n relationship
 		Table *getGeneratedTable();
@@ -291,7 +309,7 @@ class Relationship: public BaseRelationship {
 		/*! \brief Returns the generated foreign key that represents the 1-1, 1-n relationship,
 		 as well the primary key generated by the identifier relationship and the
 		 unique key used in 1-1 relationships */
-		vector<Constraint *> getGeneratedConstraints();
+		std::vector<Constraint *> getGeneratedConstraints();
 
 		virtual void configureSearchAttributes();
 
@@ -303,35 +321,30 @@ class Relationship: public BaseRelationship {
 		GenTabToken, //{gt}
 		SrcColToken; //{sc}
 
-		//! \brief Patterns ids
-		static constexpr unsigned SrcColPattern=0,
-		DstColPattern=1,
-		PkPattern=2,
-		UqPattern=3,
-		SrcFkPattern=4,
-		DstFkPattern=5,
-		PkColPattern=6;
-
 		Relationship(Relationship *rel);
 
-		Relationship(unsigned rel_type,
+		Relationship(BaseRelationship::RelType rel_type,
 					 PhysicalTable *src_tab, PhysicalTable *dst_tab,
 					 bool src_mdtry=false, bool dst_mdtry=false,
 					 bool identifier=false, bool deferrable=false,
 					 DeferralType deferral_type=DeferralType::Immediate,
 					 ActionType fk_del_act=ActionType::Null,
 					 ActionType fk_upd_act=ActionType::Null,
-					 CopyOptions copy_op = CopyOptions(0,0));
+					 CopyOptions copy_op = CopyOptions());
 
 		//! \brief  Connects the relationship making the configuration according to its type
 		void connectRelationship();
 
+		/*! \brief  Updates the columns of the relationship. This methods operates only when the
+		 *  relationship is connected but is still in an invalidated state */
+		bool updateGeneratedObjects();
+
 		/*! \brief Disconnects the relationship from the tables removing all the attributes / constraints
 			deallocating all the created object. */
 		void disconnectRelationship(bool rem_tab_objs=true);
 
 		//! \brief Defines the mandatory participation for the specified table
-		void setMandatoryTable(unsigned table_id, bool value);
+		void setMandatoryTable(TableId table_id, bool value);
 
 		/*! \brief Warning: This method is effective only when the relationship is connected. Only
 			in this situation you obtain the columns generated by connecting relationship.
@@ -346,10 +359,10 @@ class Relationship: public BaseRelationship {
 			directly create primary keys in the receiver table using columns created by the relationship.
 
 			** This feature can only be used in generalization / copy relationships ** */
-		void setSpecialPrimaryKeyCols(vector<unsigned> &cols);
+		void setSpecialPrimaryKeyCols(std::vector<unsigned> &cols);
 
 		//! \brief Returns the column indexes used by the special primary key
-		vector<unsigned> getSpecialPrimaryKeyCols();
+		std::vector<unsigned> getSpecialPrimaryKeyCols();
 
 		//! \brief Defines the name of the auto generated table on the n-n relationship
 		void setTableNameRelNN(const QString &name);
@@ -390,10 +403,10 @@ class Relationship: public BaseRelationship {
 		void setCopyOptions(CopyOptions copy_op);
 
 		//! \brief Defines the format for the specified pattern
-		void setNamePattern(unsigned pat_id, const QString &pattern);
+		void setNamePattern(PatternId pat_id, const QString &pattern);
 
 		//! \brief Gets the current format for the specified pattern
-		QString getNamePattern(unsigned pat_id);
+		QString getNamePattern(PatternId pat_id);
 
 		//! \brief Returns the current copy options
 		CopyOptions getCopyOptions();
@@ -442,7 +455,7 @@ class Relationship: public BaseRelationship {
 		Column *getAttribute(const QString &name);
 
 		//! \brief Returns the list of user added attributes
-		vector<TableObject *> getAttributes();
+		std::vector<TableObject *> getAttributes();
 
 		//! \brief Gets an constraint using its index
 		Constraint *getConstraint(unsigned constr_idx);
@@ -451,7 +464,7 @@ class Relationship: public BaseRelationship {
 		Constraint *getConstraint(const QString &name);
 
 		//! \brief Returns the list of user added constraints
-		vector<TableObject *> getConstraints();
+		std::vector<TableObject *> getConstraints();
 
 		/*! \brief Returns the index of a relationship attribute or constraint. Returns -1
 		 when the object doesn't exists */
@@ -495,7 +508,7 @@ class Relationship: public BaseRelationship {
 		bool isSiglePKColumn();
 
 		//! \brief Returns SQL / XML definition for the relationship.
-		virtual QString getCodeDefinition(unsigned def_type) final;
+		virtual QString getSourceCode(SchemaParser::CodeType def_type) final;
 
 		//! \brief Copies the attributes from one relationship to another
 		void operator = (Relationship &rel);
