@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ View::View() : BaseTable()
 View::~View()
 {
 	ObjectType types[]={ ObjectType::Trigger, ObjectType::Rule, ObjectType::Index };
-	vector<TableObject *> *list=nullptr;
+	std::vector<TableObject *> *list=nullptr;
 
 	for(unsigned i=0; i < 3; i++)
 	{
@@ -69,8 +69,8 @@ void View::setProtected(bool value)
 {
 	ObjectType obj_types[]={ ObjectType::Rule, ObjectType::Trigger };
 	unsigned i;
-	vector<TableObject *>::iterator itr, itr_end;
-	vector<TableObject *> *list=nullptr;
+	std::vector<TableObject *>::iterator itr, itr_end;
+	std::vector<TableObject *> *list=nullptr;
 
 	//Protected the table child objects
 	for(i=0; i < sizeof(obj_types)/sizeof(ObjectType); i++)
@@ -144,7 +144,7 @@ void View::setCommomTableExpression(const QString &expr)
 
 bool View::hasDefinitionExpression()
 {
-	vector<Reference>::iterator itr;
+	std::vector<Reference>::iterator itr;
 	bool found=false;
 
 	itr=references.begin();
@@ -164,7 +164,7 @@ QString View::getCommomTableExpression()
 
 int View::getReferenceIndex(Reference &refer)
 {
-	vector<Reference>::iterator itr, itr_end;
+	std::vector<Reference>::iterator itr, itr_end;
 	bool found=false;
 	int idx=-1;
 
@@ -182,18 +182,21 @@ int View::getReferenceIndex(Reference &refer)
 	return idx;
 }
 
-vector<unsigned> *View::getExpressionList(unsigned sql_type)
+std::vector<unsigned> *View::getExpressionList(Reference::SqlType sql_type)
 {
-	if(sql_type==Reference::SqlReferSelect)
+	if(sql_type==Reference::SqlSelect)
 		return &exp_select;
-	else if(sql_type==Reference::SqlReferFrom)
+
+	if(sql_type==Reference::SqlFrom)
 		return &exp_from;
-	else if(sql_type==Reference::SqlReferWhere)
+
+	if(sql_type==Reference::SqlWhere)
 		return &exp_where;
-	else if(sql_type==Reference::SqlReferEndExpr)
+
+	if(sql_type==Reference::SqlEndExpr)
 		return &exp_end;
-	else
-		return nullptr;
+
+	return nullptr;
 }
 
 void View::generateColumns()
@@ -208,7 +211,7 @@ void View::generateColumns()
 
 	if(hasDefinitionExpression())
 	{
-		vector<SimpleColumn> ref_cols = references[0].getColumns();
+		std::vector<SimpleColumn> ref_cols = references[0].getColumns();
 
 		if(ref_cols.empty())
 			columns.push_back(SimpleColumn(QString("%1...").arg(references[0].getExpression().simplified().mid(0, 20)),
@@ -267,19 +270,19 @@ void View::generateColumns()
 	}
 }
 
-vector<SimpleColumn> View::getColumns()
+std::vector<SimpleColumn> View::getColumns()
 {
 	return columns;
 }
 
-void View::addReference(Reference &refer, unsigned sql_type, int expr_id)
+void View::addReference(Reference &refer, Reference::SqlType sql_type, int expr_id)
 {
 	int idx;
-	vector<unsigned> *expr_list=nullptr;
+	std::vector<unsigned> *expr_list=nullptr;
 	Column *col=nullptr;
 
 	//Specific tests for expressions used as view definition
-	if(sql_type==Reference::SqlViewDefinition)
+	if(sql_type==Reference::SqlViewDef)
 	{
 		//Raises an error if the expression is empty
 		if(refer.getExpression().isEmpty())
@@ -302,12 +305,12 @@ void View::addReference(Reference &refer, unsigned sql_type, int expr_id)
 	if(idx < 0)
 	{
 		//Inserts the reference on the view
-		refer.setDefinitionExpression(sql_type==Reference::SqlViewDefinition);
+		refer.setDefinitionExpression(sql_type==Reference::SqlViewDef);
 		references.push_back(refer);
 		idx=references.size()-1;
 	}
 
-	if(sql_type!=Reference::SqlViewDefinition)
+	if(sql_type!=Reference::SqlViewDef)
 	{
 		//Gets the expression list
 		expr_list=getExpressionList(sql_type);
@@ -340,37 +343,31 @@ unsigned View::getReferenceCount()
 	return references.size();
 }
 
-unsigned View::getReferenceCount(unsigned sql_type, int ref_type)
+unsigned View::getReferenceCount(Reference::SqlType sql_type, int ref_type)
 {
-	vector<unsigned> *vect_idref=getExpressionList(sql_type);
+	std::vector<unsigned> *vect_idref=getExpressionList(sql_type);
 
 	if(!vect_idref)
 	{
-		if(sql_type==Reference::SqlViewDefinition)
+		if(sql_type==Reference::SqlViewDef)
 			return references.size();
-		else
-			return 0;
+
+		return 0;
 	}
 	else
 	{
 		if(ref_type < 0)
 			return vect_idref->size();
-		else
+
+		unsigned count=0;
+
+		for(auto &ref : *vect_idref)
 		{
-			vector<unsigned>::iterator itr, itr_end;
-			unsigned count=0;
-
-
-			itr=vect_idref->begin();
-			itr_end=vect_idref->end();
-			while(itr!=itr_end)
-			{
-				if(references[(*itr)].getReferenceType()==static_cast<unsigned>(ref_type)) count++;
-				itr++;
-			}
-
-			return count;
+			if(references[ref].getReferenceType()== static_cast<Reference::ReferType>(ref_type))
+				count++;
 		}
+
+		return count;
 	}
 }
 
@@ -383,15 +380,15 @@ Reference View::getReference(unsigned ref_id)
 	return references[ref_id];
 }
 
-Reference View::getReference(unsigned ref_id, unsigned sql_type)
+Reference View::getReference(unsigned ref_id, Reference::SqlType sql_type)
 {
-	vector<unsigned> *vect_idref=getExpressionList(sql_type);
+	std::vector<unsigned> *vect_idref=getExpressionList(sql_type);
 
 	//Raises an error if the reference id is out of bound
 	if(ref_id >= references.size())
 		throw Exception(ErrorCode::RefObjectInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 
-	if(sql_type==Reference::SqlViewDefinition || vect_idref)
+	if(sql_type==Reference::SqlViewDef || vect_idref)
 		return references[ref_id];
 	else
 		return references[vect_idref->at(ref_id)];
@@ -399,8 +396,8 @@ Reference View::getReference(unsigned ref_id, unsigned sql_type)
 
 void View::removeReference(unsigned ref_id)
 {
-	vector<unsigned> *vect_idref[4]={&exp_select, &exp_from, &exp_where, &exp_end};
-	vector<unsigned>::iterator itr, itr_end;
+	std::vector<unsigned> *vect_idref[4]={&exp_select, &exp_from, &exp_where, &exp_end};
+	std::vector<unsigned>::iterator itr, itr_end;
 	unsigned i;
 
 	//Raises an error if the reference id is out of bound
@@ -439,9 +436,9 @@ void View::removeReferences()
 	setCodeInvalidated(true);
 }
 
-void View::removeReference(unsigned expr_id, unsigned sql_type)
+void View::removeReference(unsigned expr_id, Reference::SqlType sql_type)
 {
-	vector<unsigned> *vect_idref=getExpressionList(sql_type);
+	std::vector<unsigned> *vect_idref=getExpressionList(sql_type);
 
 	if(expr_id >= vect_idref->size())
 		throw Exception(ErrorCode::RefObjectInvalidIndex,__PRETTY_FUNCTION__,__FILE__,__LINE__);
@@ -450,19 +447,19 @@ void View::removeReference(unsigned expr_id, unsigned sql_type)
 	setCodeInvalidated(true);
 }
 
-int View::getReferenceIndex(Reference &ref, unsigned sql_type)
+int View::getReferenceIndex(Reference &ref, Reference::SqlType sql_type)
 {
-	vector<unsigned> *vet_idref=getExpressionList(sql_type);
-	vector<unsigned>::iterator itr, itr_end;
+	std::vector<unsigned> *vet_idref=getExpressionList(sql_type);
+	std::vector<unsigned>::iterator itr, itr_end;
 	int idx_ref;
 	bool found=false;
 
 	idx_ref=getReferenceIndex(ref);
 
-	if(sql_type==Reference::SqlViewDefinition &&
+	if(sql_type==Reference::SqlViewDef &&
 			idx_ref >=0 && ref.isDefinitionExpression())
 		return idx_ref;
-	else if(sql_type!=Reference::SqlViewDefinition)
+	else if(sql_type!=Reference::SqlViewDef)
 	{
 		itr=vet_idref->begin();
 		itr_end=vet_idref->end();
@@ -494,13 +491,14 @@ void View::setDefinitionAttribute()
 		}
 		else
 		{
-			vector<unsigned> *refs_vect[4]={&exp_select, &exp_from, &exp_where, &exp_end};
-			vector<unsigned>::iterator itr, itr_end;
+			std::vector<unsigned> *refs_vect[4]={&exp_select, &exp_from, &exp_where, &exp_end};
+			std::vector<unsigned>::iterator itr, itr_end;
 			QString keywords[4]={"SELECT\n", "\nFROM\n", "\nWHERE\n", "\n"};
-			unsigned i, cnt, idx, sql_type[4]={ Reference::SqlReferSelect,
-																					Reference::SqlReferFrom,
-																					Reference::SqlReferWhere,
-																					Reference::SqlReferEndExpr };
+			unsigned i, cnt, idx;
+			Reference::SqlType sql_type[4]={ Reference::SqlSelect,
+																						Reference::SqlFrom,
+																						Reference::SqlWhere,
+																						Reference::SqlEndExpr };
 
 			for(i=0; i < 4; i++)
 			{
@@ -517,8 +515,8 @@ void View::setDefinitionAttribute()
 						itr++;
 					}
 
-					if(sql_type[i]==Reference::SqlReferSelect ||
-							sql_type[i]==Reference::SqlReferFrom)
+					if(sql_type[i]==Reference::SqlSelect ||
+							sql_type[i]==Reference::SqlFrom)
 					{
 						//Removing the final comma from SELECT / FROM declarations
 						cnt=decl.size();
@@ -531,7 +529,7 @@ void View::setDefinitionAttribute()
 	}
 
 	decl=decl.trimmed();
-	if(!decl.isEmpty() && !decl.endsWith(QChar(';')))
+	if(!decl.isEmpty() && !decl.endsWith(QChar(';')) && !with_no_data)
 		decl.append(QChar(';'));
 
 	attributes[Attributes::Definition]=decl;
@@ -544,7 +542,7 @@ void View::setReferencesAttribute()
 											Attributes::FromExp,
 											Attributes::SimpleExp,
 											Attributes::EndExp};
-	vector<unsigned> *vect_exp[]={&exp_select, &exp_from, &exp_where, &exp_end};
+	std::vector<unsigned> *vect_exp[]={&exp_select, &exp_from, &exp_where, &exp_end};
 	int cnt, i, i1;
 
 	cnt=references.size();
@@ -582,9 +580,9 @@ bool View::isReferRelationshipAddedColumn()
 	return found;
 }
 
-vector<Column *> View::getRelationshipAddedColumns()
+std::vector<Column *> View::getRelationshipAddedColumns()
 {
-	vector<Column *> cols;
+	std::vector<Column *> cols;
 	Column *col=nullptr;
 
 	for(auto &ref : references)
@@ -633,7 +631,7 @@ bool View::isReferencingColumn(Column *col)
 	return found;
 }
 
-QString View::getCodeDefinition(unsigned def_type)
+QString View::getSourceCode(SchemaParser::CodeType def_type)
 {
 	QString code_def=getCachedCode(def_type, false);
 	if(!code_def.isEmpty()) return code_def;
@@ -645,14 +643,14 @@ QString View::getCodeDefinition(unsigned def_type)
 	attributes[Attributes::Columns]="";
 	attributes[Attributes::Tag]="";
 	attributes[Attributes::Pagination]=(pagination_enabled ? Attributes::True : "");
-	attributes[Attributes::CollapseMode]=QString::number(enum_cast(collapse_mode));
+	attributes[Attributes::CollapseMode]=QString::number(collapse_mode);
 	attributes[Attributes::AttribsPage]=(pagination_enabled ? QString::number(curr_page[AttribsSection]) : "");
 	attributes[Attributes::ExtAttribsPage]=(pagination_enabled ? QString::number(curr_page[ExtAttribsSection]) : "");
 
 	setSQLObjectAttribute();
 	setLayersAttribute();
 
-	// We use column names only if the view has references that aren't its whole definition (Reference::SqlViewDefinition)
+	// We use column names only if the view has references that aren't its whole definition (Reference::SqlViewDef)
 	if(recursive && !hasDefinitionExpression())
 	{
 		QStringList fmt_names;
@@ -666,10 +664,10 @@ QString View::getCodeDefinition(unsigned def_type)
 		attributes[Attributes::Columns]=fmt_names.join(',');
 	}
 
-	if(tag && def_type==SchemaParser::XmlDefinition)
-		attributes[Attributes::Tag]=tag->getCodeDefinition(def_type, true);
+	if(tag && def_type==SchemaParser::XmlCode)
+		attributes[Attributes::Tag]=tag->getSourceCode(def_type, true);
 
-	if(def_type==SchemaParser::SqlDefinition)
+	if(def_type==SchemaParser::SqlCode)
 		setDefinitionAttribute();
 	else
 	{
@@ -680,7 +678,7 @@ QString View::getCodeDefinition(unsigned def_type)
 		attributes[Attributes::MaxObjCount]=QString::number(static_cast<unsigned>(getMaxObjectCount() * 1.20));
 	}
 
-	return BaseObject::__getCodeDefinition(def_type);
+	return BaseObject::__getSourceCode(def_type);
 }
 
 void View::setSQLObjectAttribute()
@@ -693,7 +691,7 @@ QString View::getUniqueColumnName(const QString &name)
 {
 	unsigned idx = 1;
 	QString fmt_name = name;
-	vector<SimpleColumn>::iterator itr, itr_end;
+	std::vector<SimpleColumn>::iterator itr, itr_end;
 
 	itr = columns.begin();
 	itr_end = columns.end();
@@ -727,7 +725,7 @@ void View::setObjectListsCapacity(unsigned capacity)
 unsigned View::getMaxObjectCount()
 {
   unsigned count = 0, max = references.size();
-  vector<ObjectType> types = { ObjectType::Index, ObjectType::Rule, ObjectType::Trigger };
+  std::vector<ObjectType> types = { ObjectType::Index, ObjectType::Rule, ObjectType::Trigger };
 
   for(auto type : types)
   {
@@ -738,10 +736,10 @@ unsigned View::getMaxObjectCount()
 	return max;
 }
 
-QString View::getDropDefinition(bool cascade)
+QString View::getDropCode(bool cascade)
 {
 	setSQLObjectAttribute();
-	return BaseObject::getDropDefinition(cascade);
+	return BaseObject::getDropCode(cascade);
 }
 
 
@@ -753,8 +751,8 @@ int View::getObjectIndex(BaseObject *obj)
 		return -1;
 	else
 	{
-		vector<TableObject *>::iterator itr, itr_end;
-		vector<TableObject *> *obj_list=getObjectList(obj->getObjectType());
+		std::vector<TableObject *>::iterator itr, itr_end;
+		std::vector<TableObject *> *obj_list=getObjectList(obj->getObjectType());
 		bool found=false;
 
 		if(!obj_list)
@@ -782,8 +780,8 @@ int View::getObjectIndex(const QString &name, ObjectType obj_type)
 		return -1;
 	else
 	{
-		vector<TableObject *>::iterator itr, itr_end;
-		vector<TableObject *> *obj_list=getObjectList(obj_type);
+		std::vector<TableObject *>::iterator itr, itr_end;
+		std::vector<TableObject *> *obj_list=getObjectList(obj_type);
 		bool found=false, format=name.contains('"');
 
 		if(!obj_list)
@@ -813,7 +811,7 @@ void View::addObject(BaseObject *obj, int obj_idx)
 	{
 		try
 		{
-			vector<TableObject *> *obj_list = getObjectList(obj->getObjectType());
+			std::vector<TableObject *> *obj_list = getObjectList(obj->getObjectType());
 			TableObject *tab_obj=dynamic_cast<TableObject *>(obj);
 
 			//Raises an error if already exists a object with the same name and type
@@ -829,7 +827,7 @@ void View::addObject(BaseObject *obj, int obj_idx)
 
 			//Validates the object definition
 			tab_obj->setParentTable(this);
-			tab_obj->getCodeDefinition(SchemaParser::SqlDefinition);
+			tab_obj->getSourceCode(SchemaParser::SqlCode);
 
 			//Make a additional validation if the object is a trigger
 			if(tab_obj->getObjectType()==ObjectType::Trigger)
@@ -894,8 +892,8 @@ void View::addIndex(Index *index, int obj_idx)
 
 void View::removeObject(unsigned obj_idx, ObjectType obj_type)
 {
-	vector<TableObject *> *obj_list = getObjectList(obj_type);
-	vector<TableObject *>::iterator itr;
+	std::vector<TableObject *> *obj_list = getObjectList(obj_type);
+	std::vector<TableObject *>::iterator itr;
 
 	//Raises an error if the object index is out of bound
 	if(obj_idx >= obj_list->size())
@@ -969,7 +967,7 @@ void View::removeIndex(unsigned idx)
 
 TableObject *View::getObject(unsigned obj_idx, ObjectType obj_type)
 {
-	vector<TableObject *> *obj_list=getObjectList(obj_type);
+	std::vector<TableObject *> *obj_list=getObjectList(obj_type);
 
 	//Raises an error if the object index is out of bound
 	if(obj_idx >= obj_list->size())
@@ -1034,7 +1032,7 @@ Index *View::getIndex(unsigned obj_idx)
 
 unsigned View::getObjectCount(ObjectType obj_type, bool)
 {
-	vector<TableObject *> *obj_list = getObjectList(obj_type);
+	std::vector<TableObject *> *obj_list = getObjectList(obj_type);
 	return (!obj_list ? 0 : obj_list->size());
 }
 
@@ -1053,7 +1051,7 @@ unsigned View::getIndexCount()
 	return indexes.size();
 }
 
-vector<TableObject *> *View::getObjectList(ObjectType obj_type)
+std::vector<TableObject *> *View::getObjectList(ObjectType obj_type)
 {
 	if(obj_type==ObjectType::Trigger)
 		return &triggers;
@@ -1108,10 +1106,10 @@ void View::operator = (View &view)
 	PgSqlType::renameUserType(prev_name, this, this->getName(true));
 }
 
-vector<BaseObject *> View::getObjects(const vector<ObjectType> &excl_types)
+std::vector<BaseObject *> View::getObjects(const std::vector<ObjectType> &excl_types)
 {
-	vector<BaseObject *> list;
-	vector<ObjectType> types={ ObjectType::Trigger, ObjectType::Index, ObjectType::Rule };
+	std::vector<BaseObject *> list;
+	std::vector<ObjectType> types={ ObjectType::Trigger, ObjectType::Index, ObjectType::Rule };
 
 	for(auto type : types)
 	{
@@ -1124,13 +1122,11 @@ vector<BaseObject *> View::getObjects(const vector<ObjectType> &excl_types)
 	return list;
 }
 
-QString View::getDataDictionary(bool split, attribs_map extra_attribs)
+QString View::getDataDictionary(bool split, const attribs_map &extra_attribs)
 {
 	attribs_map attribs, aux_attrs;
 	QStringList tab_names, col_names;
-	QString view_dict_file = GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir, getSchemaName()),
-			col_dict_file = GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir, Attributes::Column),
-			link_dict_file = GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir, Attributes::Link);
+	QString link_dict_file = GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir, Attributes::Link);
 
 	attribs.insert(extra_attribs.begin(), extra_attribs.end());
 	attribs[Attributes::Type] = getTypeName();
@@ -1139,40 +1135,74 @@ QString View::getDataDictionary(bool split, attribs_map extra_attribs)
 	attribs[Attributes::Name] = obj_name;
 	attribs[Attributes::Schema] = schema ? schema->getName() : "";
 	attribs[Attributes::Comment] = comment;
-	attribs[Attributes::Columns] = "";
+	attribs[Attributes::Objects] = "";
 
 	aux_attrs[Attributes::Split] = attribs[Attributes::Split];
 
-	for(auto &ref : references)
+	try
 	{
-		if(ref.getTable())
+		for(auto &ref : references)
 		{
-			aux_attrs[Attributes::Name] = ref.getTable()->getSignature().remove(QChar('"'));
-			tab_names.push_back(schparser.getCodeDefinition(link_dict_file, aux_attrs));
+			if(ref.getTable())
+			{
+				aux_attrs[Attributes::Name] = ref.getTable()->getSignature().remove(QChar('"'));
+				tab_names.push_back(schparser.getSourceCode(link_dict_file, aux_attrs));
+			}
+
+			for(auto &tab : ref.getReferencedTables())
+			{
+				aux_attrs[Attributes::Name] = tab->getSignature().remove(QChar('"'));
+				tab_names.push_back(schparser.getSourceCode(link_dict_file, aux_attrs));
+			}
 		}
 
-		for(auto &tab : ref.getReferencedTables())
+		tab_names.removeDuplicates();
+		attribs[Attributes::References] = tab_names.join(", ");
+		aux_attrs.clear();
+
+		for(auto &col : columns)
 		{
-			aux_attrs[Attributes::Name] = tab->getSignature().remove(QChar('"'));
-			tab_names.push_back(schparser.getCodeDefinition(link_dict_file, aux_attrs));
+			aux_attrs[Attributes::Parent] = getSchemaName();
+			aux_attrs[Attributes::Name] = col.name;
+			aux_attrs[Attributes::Type] = col.type;
+
+			schparser.ignoreUnkownAttributes(true);
+			attribs[Attributes::Columns] += schparser.getSourceCode(GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir,
+																																																			BaseObject::getSchemaName(ObjectType::Column)), aux_attrs);
+			aux_attrs.clear();
 		}
-	}
 
-	tab_names.removeDuplicates();
-	attribs[Attributes::References] = tab_names.join(", ");
-	aux_attrs.clear();
+		for(auto &obj : triggers)
+		{
+			attribs[Attributes::Triggers] +=
+					dynamic_cast<Trigger *>(obj)->getDataDictionary({{ Attributes::Split, attribs[Attributes::Split] }});
+		}
 
-	for(auto &col : columns)
-	{
-		aux_attrs[Attributes::Parent] = getSchemaName();
-		aux_attrs[Attributes::Name] = col.name;
-		aux_attrs[Attributes::Type] = col.type;
+		for(auto &obj : indexes)
+			attribs[Attributes::Indexes] +=  dynamic_cast<Index *>(obj)->getDataDictionary();
 
 		schparser.ignoreUnkownAttributes(true);
-		attribs[Attributes::Columns] += schparser.getCodeDefinition(col_dict_file, aux_attrs);
-		aux_attrs.clear();
+		attribs[Attributes::Objects] += schparser.getSourceCode(GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir,
+																																																		Attributes::Objects), attribs);
+		schparser.ignoreEmptyAttributes(true);
+		return schparser.getSourceCode(GlobalAttributes::getSchemaFilePath(GlobalAttributes::DataDictSchemaDir,
+																																					 getSchemaName()), attribs);
+	}
+	catch(Exception &e)
+	{
+		throw Exception(e.getErrorMessage(), e.getErrorCode(), __PRETTY_FUNCTION__, __FILE__, __LINE__, &e);
+	}
+}
+
+QString View::getAlterCode(BaseObject *object)
+{
+	try
+	{
+		attributes[Attributes::Materialized] = (materialized ? Attributes::True : "");
+		return BaseObject::getAlterCode(object);
+	}
+	catch(Exception &e)
+	{
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__,&e);
 	}
-
-	schparser.ignoreEmptyAttributes(true);
-	return schparser.getCodeDefinition(view_dict_file, attribs);
 }
