@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,9 +33,6 @@ ViewWidget::ViewWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Vi
 		QGridLayout *grid=nullptr;
 		QVBoxLayout *vbox=nullptr;
 
-		map<QString, vector<QWidget *> > fields_map;
-		QFrame *frame=nullptr;
-
 		Ui_ViewWidget::setupUi(this);
 
 		code_txt=new NumberedTextEditor(this);
@@ -43,17 +40,17 @@ ViewWidget::ViewWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Vi
 		code_hl=new SyntaxHighlighter(code_txt);
 		code_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
 		vbox=new QVBoxLayout(code_prev_tab);
-		vbox->setContentsMargins(4,4,4,4);
+		vbox->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
 		vbox->addWidget(code_txt);
 
 		cte_expression_txt=new NumberedTextEditor(this, true);
 		cte_expression_hl=new SyntaxHighlighter(cte_expression_txt);
 		cte_expression_hl->loadConfiguration(GlobalAttributes::getSQLHighlightConfPath());
 		vbox=new QVBoxLayout(cte_tab);
-		vbox->setContentsMargins(4,4,4,4);
+		vbox->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
 		vbox->addWidget(cte_expression_txt);
 
-		tag_sel=new ObjectSelectorWidget(ObjectType::Tag, false, this);
+		tag_sel=new ObjectSelectorWidget(ObjectType::Tag, this);
 		dynamic_cast<QGridLayout *>(options_gb->layout())->addWidget(tag_sel, 0, 1, 1, 4);
 
 		references_tab=new ObjectsTableWidget(ObjectsTableWidget::AllButtons ^ ObjectsTableWidget::UpdateButton, true, this);
@@ -65,7 +62,7 @@ ViewWidget::ViewWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Vi
 		references_tab->setHeaderLabel(tr("Reference alias"), 4);
 
 		vbox=new QVBoxLayout(tabWidget->widget(0));
-		vbox->setContentsMargins(4,4,4,4);
+		vbox->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
 		vbox->addWidget(references_tab);
 
 		cte_expression_cp=new CodeCompletionWidget(cte_expression_txt, true);
@@ -80,14 +77,14 @@ ViewWidget::ViewWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Vi
 
 			grid=new QGridLayout;
 			grid->addWidget(tab, 0,0,1,1);
-			grid->setContentsMargins(4,4,4,4);
+			grid->setContentsMargins(GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin,GuiUtilsNs::LtMargin);
 			tabWidget->widget(tab_id)->setLayout(grid);
 
-			connect(tab, SIGNAL(s_rowsRemoved()), this, SLOT(removeObjects()));
-			connect(tab, SIGNAL(s_rowRemoved(int)), this, SLOT(removeObject(int)));
-			connect(tab, SIGNAL(s_rowAdded(int)), this, SLOT(handleObject()));
-			connect(tab, SIGNAL(s_rowEdited(int)), this, SLOT(handleObject()));
-			connect(tab, SIGNAL(s_rowDuplicated(int,int)), this, SLOT(duplicateObject(int,int)));
+			connect(tab, &ObjectsTableWidget::s_rowsRemoved, this, &ViewWidget::removeObjects);
+			connect(tab, &ObjectsTableWidget::s_rowRemoved, this, &ViewWidget::removeObject);
+			connect(tab, &ObjectsTableWidget::s_rowAdded, this, &ViewWidget::handleObject);
+			connect(tab, &ObjectsTableWidget::s_rowEdited, this, &ViewWidget::handleObject);
+			connect(tab, &ObjectsTableWidget::s_rowDuplicated, this, &ViewWidget::duplicateObject);
 		}
 
 		objects_tab_map[ObjectType::Trigger]->setColumnCount(6);
@@ -121,29 +118,22 @@ ViewWidget::ViewWidget(QWidget *parent): BaseObjectWidget(parent, ObjectType::Vi
 		tablespace_lbl->setEnabled(false);
 		configureFormLayout(view_grid, ObjectType::View);
 
-		fields_map[generateVersionsInterval(AfterVersion, PgSqlVersions::PgSqlVersion93)].push_back(recursive_rb);
-		fields_map[generateVersionsInterval(AfterVersion, PgSqlVersions::PgSqlVersion93)].push_back(materialized_rb);
-		fields_map[generateVersionsInterval(AfterVersion, PgSqlVersions::PgSqlVersion93)].push_back(with_no_data_chk);
-		frame=generateVersionWarningFrame(fields_map);
-		view_grid->addWidget(frame, view_grid->count()+1, 0, 1,3);
-		frame->setParent(this);
+		connect(references_tab, &ObjectsTableWidget::s_rowAdded, this, &ViewWidget::addReference);
+		connect(references_tab, &ObjectsTableWidget::s_rowEdited, this, &ViewWidget::editReference);
+		connect(references_tab, &ObjectsTableWidget::s_rowDuplicated, this, &ViewWidget::duplicateReference);
+		connect(tabWidget, &QTabWidget::currentChanged, this, &ViewWidget::updateCodePreview);
 
-		connect(references_tab, SIGNAL(s_rowAdded(int)), this, SLOT(addReference(int)));
-		connect(references_tab, SIGNAL(s_rowEdited(int)), this, SLOT(editReference(int)));
-		connect(references_tab, SIGNAL(s_rowDuplicated(int,int)), this, SLOT(duplicateReference(int,int)));
-		connect(tabWidget, SIGNAL(currentChanged(int)), this, SLOT(updateCodePreview()));
+		connect(materialized_rb, &QRadioButton::toggled, with_no_data_chk, &QCheckBox::setEnabled);
+		connect(materialized_rb, &QRadioButton::toggled, tablespace_sel, &ObjectSelectorWidget::setEnabled);
+		connect(materialized_rb, &QRadioButton::toggled, tablespace_lbl, &QLabel::setEnabled);
 
-		connect(materialized_rb, SIGNAL(toggled(bool)), with_no_data_chk, SLOT(setEnabled(bool)));
-		connect(materialized_rb, SIGNAL(toggled(bool)), tablespace_sel, SLOT(setEnabled(bool)));
-		connect(materialized_rb, SIGNAL(toggled(bool)), tablespace_lbl, SLOT(setEnabled(bool)));
-
-		connect(materialized_rb, SIGNAL(toggled(bool)), this, SLOT(updateCodePreview()));
-		connect(recursive_rb, SIGNAL(toggled(bool)),  this, SLOT(updateCodePreview()));
-		connect(with_no_data_chk, SIGNAL(toggled(bool)), this, SLOT(updateCodePreview()));
-		connect(tablespace_sel, SIGNAL(s_objectSelected()), this, SLOT(updateCodePreview()));
-		connect(tablespace_sel, SIGNAL(s_selectorCleared()), this, SLOT(updateCodePreview()));
-		connect(schema_sel, SIGNAL(s_objectSelected()), this, SLOT(updateCodePreview()));
-		connect(schema_sel, SIGNAL(s_selectorCleared()), this, SLOT(updateCodePreview()));
+		connect(materialized_rb, &QRadioButton::toggled, this, &ViewWidget::updateCodePreview);
+		connect(recursive_rb,  &QRadioButton::toggled,  this, &ViewWidget::updateCodePreview);
+		connect(with_no_data_chk, &QCheckBox::toggled, this, &ViewWidget::updateCodePreview);
+		connect(tablespace_sel, &ObjectSelectorWidget::s_objectSelected, this, &ViewWidget::updateCodePreview);
+		connect(tablespace_sel, &ObjectSelectorWidget::s_selectorCleared, this, &ViewWidget::updateCodePreview);
+		connect(schema_sel, &ObjectSelectorWidget::s_objectSelected, this, &ViewWidget::updateCodePreview);
+		connect(schema_sel, &ObjectSelectorWidget::s_selectorCleared, this, &ViewWidget::updateCodePreview);
 
 		configureTabOrder({ tag_sel, ordinary_rb, recursive_rb, with_no_data_chk, tabWidget });
 		setMinimumSize(660, 650);
@@ -227,7 +217,7 @@ void ViewWidget::duplicateObject(int curr_row, int new_row)
 		CoreUtilsNs::copyObject(&dup_object, object, obj_type);
 		dup_object->setName(CoreUtilsNs::generateUniqueName(dup_object, *view->getObjectList(obj_type), false, QString("_cp")));
 
-		op_id=op_list->registerObject(dup_object, Operation::ObjectCreated, new_row, this->object);
+		op_id=op_list->registerObject(dup_object, Operation::ObjCreated, new_row, this->object);
 
 		view->addObject(dup_object);
 		view->setModified(true);
@@ -264,7 +254,7 @@ void ViewWidget::removeObjects()
 		{
 			object=view->getObject(0, obj_type);
 			view->removeObject(object);
-			op_list->registerObject(object, Operation::ObjectRemoved, 0, this->object);
+			op_list->registerObject(object, Operation::ObjRemoved, 0, this->object);
 		}
 	}
 	catch(Exception &e)
@@ -310,7 +300,7 @@ void ViewWidget::removeObject(int row)
 		view=dynamic_cast<View *>(this->object);
 		object=view->getObject(row, obj_type);
 		view->removeObject(object);
-		op_list->registerObject(object, Operation::ObjectRemoved, row, this->object);
+		op_list->registerObject(object, Operation::ObjRemoved, row, this->object);
 	}
 	catch(Exception &e)
 	{
@@ -325,7 +315,7 @@ ObjectType ViewWidget::getObjectType(QObject *sender)
 
 	if(sender)
 	{
-		map<ObjectType, ObjectsTableWidget *>::iterator itr, itr_end;
+		std::map<ObjectType, ObjectsTableWidget *>::iterator itr, itr_end;
 
 		itr=objects_tab_map.begin();
 		itr_end=objects_tab_map.end();
@@ -447,9 +437,9 @@ int ViewWidget::openReferenceForm(Reference ref, int row, bool update)
 	editing_form.setMainWidget(ref_wgt);
 	editing_form.setButtonConfiguration(Messagebox::OkCancelButtons);
 
-	disconnect(editing_form.apply_ok_btn, SIGNAL(clicked(bool)), &editing_form, SLOT(accept()));
-	connect(editing_form.apply_ok_btn, SIGNAL(clicked(bool)), ref_wgt, SLOT(applyConfiguration()));
-	connect(ref_wgt, SIGNAL(s_closeRequested()), &editing_form, SLOT(accept()));
+	disconnect(editing_form.apply_ok_btn, &QPushButton::clicked, &editing_form, &BaseForm::accept);
+	connect(editing_form.apply_ok_btn, &QPushButton::clicked, ref_wgt, &ReferenceWidget::applyConfiguration);
+	connect(ref_wgt, &ReferenceWidget::s_closeRequested, &editing_form, &BaseForm::accept);
 
 	ref_wgt->setAttributes(ref, getReferenceFlag(row), model);
 	result = editing_form.exec();
@@ -472,20 +462,20 @@ unsigned ViewWidget::getReferenceFlag(int row)
 		return 0;
 
 	if(flags_str[4] == '1')
-		ref_flags = Reference::SqlViewDefinition;
+		ref_flags = Reference::SqlViewDef;
 	else
 	{
 		if(flags_str[0] == '1')
-			ref_flags |= Reference::SqlReferSelect;
+			ref_flags |= Reference::SqlSelect;
 
 		if(flags_str[1] == '1')
-			ref_flags |= Reference::SqlReferFrom;
+			ref_flags |= Reference::SqlFrom;
 
 		if(flags_str[2] == '1')
-			ref_flags |= Reference::SqlReferWhere;
+			ref_flags |= Reference::SqlWhere;
 
 		if(flags_str[3] == '1')
-			ref_flags |= Reference::SqlReferEndExpr;
+			ref_flags |= Reference::SqlEndExpr;
 	}
 
 	return ref_flags;
@@ -501,11 +491,11 @@ void ViewWidget::showReferenceData(Reference refer, unsigned ref_flags, unsigned
 	PhysicalTable *tab=nullptr;
 	Column *col=nullptr;
 	QString str_aux;
-	bool	selec_from = (ref_flags & Reference::SqlReferSelect) == Reference::SqlReferSelect,
-				from_where = (ref_flags & Reference::SqlReferFrom) == Reference::SqlReferFrom,
-				after_where = (ref_flags & Reference::SqlReferWhere) == Reference::SqlReferWhere,
-				end_expr = (ref_flags & Reference::SqlReferEndExpr) == Reference::SqlReferEndExpr,
-				view_def = (ref_flags & Reference::SqlViewDefinition) == Reference::SqlViewDefinition;
+	bool	selec_from = (ref_flags & Reference::SqlSelect) == Reference::SqlSelect,
+				from_where = (ref_flags & Reference::SqlFrom) == Reference::SqlFrom,
+				after_where = (ref_flags & Reference::SqlWhere) == Reference::SqlWhere,
+				end_expr = (ref_flags & Reference::SqlEndExpr) == Reference::SqlEndExpr,
+				view_def = (ref_flags & Reference::SqlViewDef) == Reference::SqlViewDef;
 
 	if(refer.getReferenceType()==Reference::ReferColumn)
 	{
@@ -555,14 +545,14 @@ void ViewWidget::updateCodePreview()
 			View aux_view;
 			Reference refer;
 			QString str_aux;
-			TableObject *tab_obj=nullptr;
-			map<ObjectType, ObjectsTableWidget *>::iterator itr, itr_end;
-			unsigned i, count, i1, expr_type[]={
-												Reference::SqlReferSelect,
-												Reference::SqlReferFrom,
-												Reference::SqlReferWhere,
-												Reference::SqlReferEndExpr,
-												Reference::SqlViewDefinition};
+			unsigned i, count, i1;
+			Reference::SqlType expr_type[]={
+				Reference::SqlSelect,
+				Reference::SqlFrom,
+				Reference::SqlWhere,
+				Reference::SqlEndExpr,
+				Reference::SqlViewDef
+			};
 
 			aux_view.BaseObject::setName(name_edt->text().toUtf8());
 			aux_view.BaseObject::setSchema(schema_sel->getSelectedObject());
@@ -581,49 +571,20 @@ void ViewWidget::updateCodePreview()
 				//Get the SQL application string for the current reference
 				str_aux=references_tab->getCellText(i,3);
 
-				for(i1=0; i1 < sizeof(expr_type)/sizeof(unsigned); i1++)
+				for(i1=0; i1 < 5; i1++)
 				{
 					if(str_aux[i1]=='1')
 						aux_view.addReference(refer, expr_type[i1]);
 				}
 			}
 
-			itr=objects_tab_map.begin();
-			itr_end=objects_tab_map.end();
-
-			//Inserts the triggers / rules into the auxiliary view
-			while(itr!=itr_end)
-			{
-				count=itr->second->getRowCount();
-
-				//Make a copy of each view objects (rule/trigger) to the auxiliary view
-				for(i=0; i < count; i++)
-				{
-					if(itr->first==ObjectType::Trigger)
-					{
-						tab_obj=new Trigger;
-						(*dynamic_cast<Trigger *>(tab_obj))=
-								(*reinterpret_cast<Trigger *>(itr->second->getRowData(i).value<void *>()));
-					}
-					else
-					{
-						tab_obj=new Rule;
-						(*dynamic_cast<Rule *>(tab_obj))=
-								(*reinterpret_cast<Rule *>(itr->second->getRowData(i).value<void *>()));
-					}
-					aux_view.addObject(tab_obj);
-				}
-
-				itr++;
-			}
-			code_txt->setPlainText(aux_view.getCodeDefinition(SchemaParser::SqlDefinition));
+			code_txt->setPlainText(aux_view.getSourceCode(SchemaParser::SqlCode));
 		}
 	}
 	catch(Exception &e)
 	{
-		QString str_aux;
 		//In case of error no code is outputed, showing a error message in the code preview widget
-		str_aux=tr("/* Could not generate the SQL code. Make sure all attributes are correctly filled! ");
+		QString str_aux=tr("/* Could not generate the SQL code. Make sure all attributes are correctly filled! ");
 		str_aux+=QString("\n\n>> Returned error(s): \n\n%1*/").arg(e.getExceptionsText());
 		code_txt->setPlainText(str_aux);
 	}
@@ -672,20 +633,20 @@ void ViewWidget::setAttributes(DatabaseModel *model, OperationList *op_list, Sch
 		ref_flags = 0;
 		refer=view->getReference(i);
 
-		if(view->getReferenceIndex(refer, Reference::SqlViewDefinition) >= 0)
-			ref_flags = Reference::SqlViewDefinition;
+		if(view->getReferenceIndex(refer, Reference::SqlViewDef) >= 0)
+			ref_flags = Reference::SqlViewDef;
 
-		if(view->getReferenceIndex(refer, Reference::SqlReferSelect) >= 0)
-			ref_flags |= Reference::SqlReferSelect;
+		if(view->getReferenceIndex(refer, Reference::SqlSelect) >= 0)
+			ref_flags |= Reference::SqlSelect;
 
-		if(view->getReferenceIndex(refer, Reference::SqlReferFrom) >= 0)
-			ref_flags |= Reference::SqlReferFrom;
+		if(view->getReferenceIndex(refer, Reference::SqlFrom) >= 0)
+			ref_flags |= Reference::SqlFrom;
 
-		if(view->getReferenceIndex(refer, Reference::SqlReferWhere) >= 0)
-			ref_flags |= Reference::SqlReferWhere;
+		if(view->getReferenceIndex(refer, Reference::SqlWhere) >= 0)
+			ref_flags |= Reference::SqlWhere;
 
-		if(view->getReferenceIndex(refer, Reference::SqlReferEndExpr) >= 0)
-			ref_flags |= Reference::SqlReferEndExpr;
+		if(view->getReferenceIndex(refer, Reference::SqlEndExpr) >= 0)
+			ref_flags |= Reference::SqlEndExpr;
 
 		showReferenceData(refer, ref_flags, i);
 	}
@@ -704,16 +665,16 @@ void ViewWidget::applyConfiguration()
 	{
 		View *view=nullptr;
 		ObjectType types[]={ ObjectType::Trigger, ObjectType::Rule, ObjectType::Index };
-		unsigned expr_type[]={ Reference::SqlReferSelect,
-													 Reference::SqlReferFrom,
-													 Reference::SqlReferWhere,
-													 Reference::SqlReferEndExpr,
-													 Reference::SqlViewDefinition};
+		Reference::SqlType expr_type[]={ Reference::SqlSelect,
+																		 Reference::SqlFrom,
+																		 Reference::SqlWhere,
+																		 Reference::SqlEndExpr,
+																		 Reference::SqlViewDef};
 		Reference refer;
 		QString str_aux;
 
 		if(!this->new_object)
-			op_list->registerObject(this->object, Operation::ObjectModified);
+			op_list->registerObject(this->object, Operation::ObjModified);
 		else
 			registerNewObject();
 
