@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,18 +25,28 @@
 #ifndef HTML_ITEM_DELEGATE_H
 #define HTML_ITEM_DELEGATE_H
 
+#include "guiglobal.h"
 #include <QObject>
 #include <QPainter>
 #include "plaintextitemdelegate.h"
 
-class HtmlItemDelegate : public PlainTextItemDelegate {
+class __libgui HtmlItemDelegate : public PlainTextItemDelegate {
 	private:
 		Q_OBJECT
 
+		/*! \brief Indicates whether the html tags should be ignored when
+		 *  determining the size hint of the item. See sizeHint() */
+		bool ignore_tags_sz_hint;
+
+		static const QRegularExpression TagRegExp;
+
 	public:
-		HtmlItemDelegate(QObject * parent = nullptr);
+		HtmlItemDelegate(QObject * parent = nullptr, bool ignore_tags_sz_hint = false);
+
 		virtual ~HtmlItemDelegate();
 
+		QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
+
 	protected:
 		virtual void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
 };
