@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,12 +25,13 @@
 #ifndef ABOUT_WIDGET_H
 #define ABOUT_WIDGET_H
 
+#include "guiglobal.h"
 #include <QWidget>
 #include <QGraphicsDropShadowEffect>
 #include "ui_aboutwidget.h"
 #include "globalattributes.h"
 
-class AboutWidget: public QWidget, public Ui::AboutWidget {
+class __libgui AboutWidget: public QWidget, public Ui::AboutWidget {
 	private:
 		Q_OBJECT
 		
