@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,10 +19,11 @@
 #ifndef BULK_DATA_EDIT_WIDGET_H
 #define BULK_DATA_EDIT_WIDGET_H
 
+#include "guiglobal.h"
 #include <QWidget>
 #include "ui_bulkdataeditwidget.h"
 
-class BulkDataEditWidget: public QWidget, public Ui::BulkDataEditWidget {
+class __libgui BulkDataEditWidget: public QWidget, public Ui::BulkDataEditWidget {
 	private:
 		Q_OBJECT
 
