@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,10 +25,11 @@
 #ifndef SCENE_INFO_WIDGET_H
 #define SCENE_INFO_WIDGET_H
 
+#include "guiglobal.h"
 #include "ui_sceneinfowidget.h"
 #include "baseobjectview.h"
 
-class SceneInfoWidget: public QWidget, public Ui::SceneInfoWidget {
+class __libgui SceneInfoWidget: public QWidget, public Ui::SceneInfoWidget {
 	private:
 		Q_OBJECT
 
