@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -48,12 +48,14 @@ namespace Attributes {
 	AttribsPage("attribs-page"),
 	AttribsPerPage("attribs-per-page"),
 	Attribute("attribute"),
+	Attributes("attributes"),
 	AutoBrowseDb("auto-browse-db"),
 	AutoSaveInterval("autosave-interval"),
 	BackgroundColor("background-color"),
 	BaseType("base"),
 	Before("before"),
 	BehaviorType("behavior-type"),
+	Big("big"),
 	Bold("bold"),
 	BorderColor("border-color"),
 	Bottom("bottom"),
@@ -76,10 +78,8 @@ namespace Attributes {
 	CheckVersions("check-versions"),
 	CkConstr("ck-constr"),
 	ClientEncoding("client-encoding"),
-	CodeCompletion("code-completion"),
-	CodeFont("code-font"),
-	CodeFontSize("code-font-size"),
-	CodeTabWidth("code-tab-width"),
+	Code("code"),
+	CodeCompletion("code-completion"),	
 	ColIndexes("col-indexes"),
 	ColIsIdentity("col-is-identity"),
 	CollapseMode("collapse-mode"),
@@ -139,9 +139,12 @@ namespace Attributes {
 	CustomColor("custom-color"),
 	CustomFilter("custom-filter"),
 	CustomIdxs("customidxs"),
+	CustomScale("custom-scale"),
 	Cycle("cycle"),
+	Dark("dark"),
 	Database("database"),
 	DataDirectory("data-directory"),
+	DataDictIndex("datadictidx"),
 	Date("date"),
 	DbModel("dbmodel"),
 	DdlEndToken("-- ddl-end --"),
@@ -164,6 +167,7 @@ namespace Attributes {
 	DelEvent("del-event"),
 	Delimiter("delimiter"),
 	DelimitersColor("delimiters-color"),
+	Design("design"),
 	DestType("destiny-type"),
 	Deterministic("deterministic"),
 	Diff("diff"),
@@ -174,6 +178,7 @@ namespace Attributes {
 	DockWidgets("dock-widgets"),
 	DomConstraint("domconstraint"),
 	DontDropMissingObjs="dont-drop-missing-objs",
+	Dot("dot"),
 	Drop("drop"),
 	DropCmds("drop-cmds"),
 	DropMissingColsConstrs="drop-missing-cols-constrs",
@@ -233,6 +238,7 @@ namespace Attributes {
 	FilterTableTypes("filter-tab-types"),
 	FinalFunc("final"),
 	FiringType("firing-type"),
+	FirstRun("first-run"),
 	FkColumn("fk-column"),
 	FkConstr("fk-constr"),
 	FkDefs("fk-defs"),
@@ -260,6 +266,7 @@ namespace Attributes {
 	GrantOp("grant-op"),
 	GridSize("grid-size"),
 	GridColor("grid-color"),
+	GridPattern("grid-pattern"),
 	Group("group"),
 	HandlerFunc("handler"),
 	HandlesType("handles-type"),
@@ -275,6 +282,7 @@ namespace Attributes {
 	HighlightOrder("highlight-order"),
 	HistoryMaxLength("history-max-length"),
 	Icon("icon"),
+	IconsSize("icons-size"),
 	Id("id"),
 	IdentFile("ident-file"),
 	Identifier("identifier"),
@@ -343,17 +351,20 @@ namespace Attributes {
 	LeftType("left-type"),
 	Length("length"),
 	Library("library"),
+	Light("light"),
 	LikeType("like-type"),
 	Line("line"),
 	LineHighlightColor("line-highlight-color"),
 	LineNumbersBgColor("line-numbers-bg-color"),
 	LineNumbersColor("line-numbers-color"),
 	Link("link"),
+	LinkMode("link-mode"),
 	ListenAddresses("listen-addresses"),
 	Locale("locale"),
 	LocaleMod("locale-mod"),
 	LockerArc("locker-arc"),
 	LockerBody("locker-body"),
+	LockPageDelimResize("lock-page-delim-resize"),
 	Login("login"),
 	LookaheadChar("lookahead-char"),
 	LowVerbosity("low-verbosity"),
@@ -362,6 +373,7 @@ namespace Attributes {
 	Maximized("maximized"),
 	MaxObjCount("max-obj-count"),
 	MaxValue("max-value"),
+	Medium("medium"),
 	Member("member"),
 	MemberRoles("member-roles"),
 	Merges("merges"),
@@ -394,10 +406,12 @@ namespace Attributes {
 	ObjectType("object-type"),
 	ObjCount("objcount"),
 	ObjSelection("obj-selection"),
+	ObjShadow("obj-shadow"),
 	Oid("oid"),
 	OidFilterOp("oid-filter-op"),
 	Oids("oids"),
 	OldName("old-name"),
+	OldPgSqlVersions("old-pgsql-versions"),
 	OldTableName("old-table-name"),
 	OldVersion("old-version"),
 	OpClass("opclass"),
@@ -453,6 +467,7 @@ namespace Attributes {
 	PkPattern("pk-pattern"),
 	Placeholder("placeholder"),
 	Placeholders("placeholders"),
+	Plugin("plugin"),
 	Points("points"),
 	Port("port"),
 	Portrait("portrait"),
@@ -538,6 +553,7 @@ namespace Attributes {
 	SelectPriv("select"),
 	SendFunc("send"),
 	Sequence("sequence"),
+	Sequences("sequences"),
 	Server("server"),
 	ServerEncoding("server-encoding"),
 	ServerPid("server-pid"),
@@ -559,6 +575,7 @@ namespace Attributes {
 	SimplifiedObjCreation("simplified-obj-creation"),
 	SinglePkColumn("single-pk-col"),
 	Size("size"),
+	Small("small"),
 	Snippet("snippet"),
 	SortOp("sort-op"),
 	SourceEditorApp("source-editor-app"),
@@ -571,6 +588,7 @@ namespace Attributes {
 	SqlObject("sql-object"),
 	SqlTool("sqltool"),
 	SqlValidation("sql-validation"),
+	Square("square"),
 	SrcColPattern("src-col-pattern"),
 	SrcColumns("src-columns"),
 	SrcEncoding("src-encoding"),
@@ -600,6 +618,8 @@ namespace Attributes {
 	SubtypeDiffFunc("subtypediff"),
 	Superuser("superuser"),
 	Symbol("symbol"),
+	System("system"),
+	SyntaxHlTheme("syntax-hl-theme"),
 	Table("table"),
 	TableTogglerButtons("table-toggler-btns"),
 	TableTogglerBody("table-toggler-body"),
@@ -612,6 +632,7 @@ namespace Attributes {
 	TableTitle("table-title"),
 	TableType("table-type"),
 	Tag("tag"),
+	TabWidth("tab-width"),
 	TemplateDb("template"),
 	TemporaryPriv("temporary"),
 	Top("top"),
@@ -637,6 +658,7 @@ namespace Attributes {
 	Types("types"),
 	TyplesUpd("tuples-upd"),
 	UiLanguage("ui-language"),
+	UiTheme("ui-theme"),
 	Undefined("undefined"),
 	Underline("underline"),
 	Unique("unique"),
