@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,40 +21,32 @@
 
 namespace PgSqlVersions {
 	const QString
-	PgSqlVersion90 = QString("9.0"),
-	PgSqlVersion91 = QString("9.1"),
-	PgSqlVersion92 = QString("9.2"),
-	PgSqlVersion93 = QString("9.3"),
-	PgSqlVersion94 = QString("9.4"),
-	PgSqlVersion95 = QString("9.5"),
-	PgSqlVersion96 = QString("9.6"),
 	PgSqlVersion100 = QString("10.0"),
 	PgSqlVersion110 = QString("11.0"),
 	PgSqlVersion120 = QString("12.0"),
 	PgSqlVersion130 = QString("13.0"),
-	DefaulVersion = PgSqlVersion130;
+	PgSqlVersion140 = QString("14.0"),
+	PgSqlVersion150 = QString("15.0"),
+	DefaulVersion = PgSqlVersion150;
 
 	const QStringList
 	AllVersions = {
+		PgSqlVersion150, PgSqlVersion140,
 		PgSqlVersion130, PgSqlVersion120,
-		PgSqlVersion110, PgSqlVersion100,
-		PgSqlVersion96, PgSqlVersion95,
-		PgSqlVersion94, PgSqlVersion93,
-		PgSqlVersion92, PgSqlVersion91,
-		PgSqlVersion90
+		PgSqlVersion110, PgSqlVersion100
 	};
 
-	QString parseString(const QString &pgsql_ver)
+	QString parseString(const QString &pgsql_ver, bool ignore_legacy_ver)
 	{
 		unsigned curr_ver = QString(pgsql_ver).remove('.').toUInt(),
-				minor_ver = QString(PgSqlVersion90).remove('.').toUInt(),
+				minor_ver = QString(PgSqlVersion100).remove('.').toUInt(),
 				default_ver = QString(DefaulVersion).remove('.').toUInt();
 
-		if(curr_ver != 0 && (curr_ver < minor_ver))
+		if(!ignore_legacy_ver && curr_ver != 0 && (curr_ver < minor_ver))
 		{
 			throw Exception(Exception::getErrorMessage(ErrorCode::InvPostgreSQLVersion)
 							.arg(pgsql_ver)
-							.arg(PgSqlVersions::PgSqlVersion90)
+							.arg(PgSqlVersions::PgSqlVersion100)
 							.arg(PgSqlVersions::DefaulVersion),
 							ErrorCode::InvPostgreSQLVersion,__PRETTY_FUNCTION__,__FILE__,__LINE__);
 		}
