@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ void SchemaFilesSyntaxTest::schemasDontGenerateSyntaxErrors()
 
 	for(auto folder : sch_folders)
 	{
-		path = GlobalAttributes::getSchemasRootDir() + GlobalAttributes::DirSeparator + folder;
+		path = GlobalAttributes::getSchemasRootPath() + GlobalAttributes::DirSeparator + folder;
 		dir.setCurrent(path);
 		sch_files = dir.entryList({ "*.sch" }, QDir::Files | QDir::NoDotAndDotDot);
 
@@ -54,7 +54,7 @@ void SchemaFilesSyntaxTest::schemasDontGenerateSyntaxErrors()
 			{
 				schparser.ignoreEmptyAttributes(true);
 				schparser.ignoreUnkownAttributes(true);
-				schparser.getCodeDefinition(path + GlobalAttributes::DirSeparator + sch_file, attrs);
+				schparser.getSourceCode(path + GlobalAttributes::DirSeparator + sch_file, attrs);
 			}
 		}
 		catch(Exception &e)
